@@ -1,21 +1,20 @@
 /* 
-   01/05/2003 Nrg2Iso v 0.1
+   29/04/2021 Nrg2Iso v0.4.1
 
-   Copyright (C) 2003 Grgory Kokanosky <gregory.kokanosky@free.fr>
+   Copyright (C) 2003-2021 Gregory Kokanosky <gregory.kokanosky@free.fr>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
+   This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #define _FILE_OFFSET_BITS 64
@@ -29,7 +28,7 @@
 
 void usage(){
   printf("Nrg2Iso v%s by G. Kokanosky\n", VERSION);
-  printf("released under the GNU GPL v2 or later\n\n");
+  printf("released under the GNU GPL v3 or later\n\n");
 
   printf("Usage :\n");
   printf("nrg2iso image.nrg image.iso\n\n");
